flutter_link_nav library
Classes
- AppRoutes
- DeepLinkGuard
- A guard that can intercept and potentially block or redirect deep link navigation
- DeepLinkHandler
- DeepLinkProcessor
- This is class support process deep link can be override to custom process deep link
- DeepLinkRequest
- DefaultDeepLinkProcessor
- GuardResult
- Result of a DeepLinkGuard.canNavigate check
- RouteConfig
- RouteRegistry
- Configuration class for tab navigation handling
Mixins
-
TabDeepLinkMixin<
T extends StatefulWidget> - A mixin to simplify deep link handling for tab-based screens.
Extensions
- DeepLinkObjectX on Object?
-
QueryParametersX
on Map<
String, String> - UriParser on Uri
Typedefs
-
DeepLinkCallback
= FutureOr<
void> Function(BuildContext context, Uri uri) -
RouteAction
= RouteHandler<
FutureOr< void> > -
RouteHandler<
T> = T Function(Object? queryParams) -
RouteWidget
= RouteHandler<
Widget?>