AppRoutes class abstract

Constructors

AppRoutes()

Properties

hashCode int
The hash code for this object.
no setterinherited
routes Map<String, RouteConfig>
This place contains all the routes used in the application.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tabBasedRoutes Set<String>?
This set contains routes that are based on tab navigation. example: main screen contains 3 tabs screen: home, search, profile
no setter

Methods

isTabBasedRoute(String? route) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerRoutes() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance AppRoutes?
no setter

Static Methods

executeRouteAction(String routeName, {dynamic arguments}) Future<void>?
Execute an action for a specific route without navigation. Use this for action-only routes instead of Navigator.pushNamed.
generateRoute(RouteSettings settings) Route?
The route generator callback used when the app is navigated to a named route. Only handles routes with widgetRegister. For action-only routes, use deep links instead.
setInstance(AppRoutes appRoutes) → void