routes property
Map<String, RouteConfig>
get
routes
This place contains all the routes used in the application.
Implementation
Map<String, RouteConfig> get routes;
This place contains all the routes used in the application.
Map<String, RouteConfig> get routes;