DeepLinkGuard class abstract

A guard that can intercept and potentially block or redirect deep link navigation

Constructors

DeepLinkGuard()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

canNavigate(BuildContext context, DeepLinkRequest request) FutureOr<GuardResult>
Determines if the navigation to the given request is allowed
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited