DeepLinkHandler class

Constructors

DeepLinkHandler({DeepLinkListener? listener, DeepLinkProcessor? processor})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

init(BuildContext context, {DeepLinkCallback? customHandler, void onUnknownRoute(Uri uri)?, void onError(Object error, StackTrace stackTrace)?}) → void
Initialize or update the deep link handler. Can be called multiple times to update the context and customHandler.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
triggerError(Object error, StackTrace stack) → void
triggerUnknownRoute(Uri uri) → void
Exposed for internal use by processors

Operators

operator ==(Object other) bool
The equality operator.
inherited