DeepLinkRequest class

Constructors

DeepLinkRequest({required Uri uri, required String path, required Map<String, String> queryParameters, dynamic arguments})

Properties

arguments → dynamic
Optional arguments passed from Navigator or deep link processor
final
hashCode int
The hash code for this object.
no setterinherited
path String
The parsed path/route name
final
queryParameters Map<String, String>
Query parameters from the URI
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri Uri
The full URI received from the platform
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited