RouteConfig class

Constructors

RouteConfig({RouteWidget? widgetRegister, RouteAction? actionRegister, List<DeepLinkGuard>? guards})
const

Properties

actionRegister RouteAction?
final
guards List<DeepLinkGuard>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widgetRegister RouteWidget?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited