TabNavigationConfig class

Configuration class for tab navigation handling

Constructors

TabNavigationConfig({required int getTabIndex(String?), required int currentTabIndex, required void updateTabIndex(int)})
const

Properties

currentTabIndex int
final
getTabIndex int Function(String?)
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updateTabIndex → void Function(int)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited