Properties
hashCode
→ int
The hash code for this object.
no setter inherited
routes
→ Map <String , RouteConfig >
This place contains all the routes used in the application.
no setter
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
tabBasedRoutes
→ Set <String > ?
This set contains routes that are based on tab navigation.
example: main screen contains 3 tabs screen: home, search, profile
no setter
Static Methods
executeRouteAction (String routeName , {dynamic arguments })
→ Future <void > ?
Execute an action for a specific route without navigation.
Use this for action-only routes instead of Navigator.pushNamed.
generateRoute (RouteSettings settings )
→ Route ?
The route generator callback used when the app is navigated to a named route.
Only handles routes with widgetRegister. For action-only routes, use deep links instead.
setInstance (AppRoutes appRoutes )
→ void